YARP 2.1.3 (2007-02-22)                                                {#v2_1_3}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.0...v2.1.3`):

```
   307	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    21	Giorgio Metta <giorgio.metta@iit.it>
    14	YARP Developers <yarp0-devel@lists.sourceforge.net>
    12	Alexandre Bernardino <alex@isr.ist.utl.pt>
    11	Alessandro Scalzo <alessandro.scalzo@iit.it>
     9	Lorenzo Natale <lorenzo.natale@iit.it>
     3	Claudio Castellini <claudio.castellini@dlr.de>
     2	Francesco Nori <francesco.nori@iit.it>
     2	Michael Bucko <m.c.bucko@gmail.com>
     2	Naeem Assif Mirza <assif42@gmail.com>
```
